==> pluxml_5.4.orig.tar.gz: PluXml-5.4/core/lang/en/update.php <==
<?php

$LANG = array(

'L_SAVE_SUCCESSFUL'					=> 'Data was successfully saved',
'L_UPDATE_TITLE'					=> 'PluXml update',
'L_WRONG_PHP_VERSION'				=> 'PluXml requires PHP 5 or higher.',

'L_SELECT_LANG'						=> 'Choose your language',
'L_INPUT_CHANGE'					=> 'Change',

'L_UPDATE_UPTODATE'					=> 'Your PluXml has already been updated.',
'L_UPDATE_NOT_AVAILABLE'			=> 'No update available.',
'L_UPDATE_BACK'						=> 'Back to Home page',
'L_UPDATE_WARNING1'					=> 'You are about to update your old version of PluXml',
'L_UPDATE_SELECT_VERSION'			=> 'Please choose the old PluXml version you wish to update.',
'L_UPDATE_WARNING2'					=> 'If you can\'t find the old version of PluXml in the list below, then there is no automatic procedure to update, because your version is too old.<br />We advise you to download the latest version of <a href="http://www.pluxml.org">PluXml</a> and to make a new installation.',
'L_UPDATE_WARNING3'					=> 'Warning: before you start updating, don\'t forget to save a copy of your site by copying the "data" folder',
'L_UPDATE_START'					=> 'Start the update',

'L_UPDATE_ENDED'					=> 'Update complete',
'L_UPDATE_INPROGRESS'				=> 'Applying version updates',
'L_UPDATE_ERROR'					=> 'An error occured during the update.',
'L_UPDATE_SUCCESSFUL'				=> 'All the updates were successfully completed !',

'L_UPDATE_UPDATE_PARAMETERS_FILE'	=> 'Updating parametres.xml',
'L_UPDATE_CREATE_TAGS_FILE'			=> 'Creating tags.xml',
'L_UPDATE_ERR_CREATE_TAGS_FILE'		=> 'An error occured while creating tags.xml',
'L_UPDATE_CREATE_THEME_FILE'		=> 'Creating the theme file',
'L_UPDATE_ERR_CREATE_THEME_FILE'	=> 'An error occured while creating the file',
'L_UPDATE_ARTICLES_CONVERSION'		=> 'Converting articles to new format',
'L_UPDATE_ERR_FILE_PROCESSING'		=> 'Error in file processing',
'L_UPDATE_STATICS_MIGRATION'		=> 'Static page file migration',
'L_UPDATE_ERR_STATICS_MIGRATION'	=> 'An error occured while migrating static pages file',
'L_UPDATE_CREATE_USERS_FILE'		=> 'Creating users\' file',
'L_UPDATE_ERR_CREATE_USERS_FILE'	=> 'An error occured while creating users file',
'L_UPDATE_USERS_MIGRATION'			=> 'Migrating users\' file',
'L_UPDATE_ERR_USERS_MIGRATION'		=> 'An error occured while migrating users file',
'L_UPDATE_ERR_NO_USERS'				=> 'No user in the file',
'L_UPDATE_CREATE_HTACCESS_FILE'		=> 'Creating .htaccess file',
'L_UPDATE_ERR_CREATE_HTACCESS_FILE'	=> 'An error occured while creating .htaccess file',
'L_UPDATE_UPDATE_HTACCESS_FILE'		=> 'Updating .htaccess file',
'L_UPDATE_ERR_UPDATE_HTACCESS_FILE'	=> 'An error occured while updating .htaccess file',
'L_UPDATE_CATEGORIES_MIGRATION'		=> 'Migrating category file',
'L_UPDATE_ERR_CATEGORIES_MIGRATION'	=> 'An error occured while migrating category file',
'L_UPDATE_CREATE_PLUGINS_FILE'		=> 'Creating plugins.xml',
'L_UPDATE_ERR_CREATE_PLUGINS_FILE'	=> 'An error occured while creating plugins.xml',
'L_UPDATE_DELETE_FULLSCREEN_FILE'	=> 'Deleting core/admin/fullscreen.php',
'L_UPDATE_ERR_DELETE_FULLSCREEN_FILE'=> 'An error occured while deleting core/admin/fullscreen.php',
'L_UPDATE_DELETE_PLXTOOLBAR_FOLDER'	=>	'Deleting core/plxtoolbar/ folder',
'L_UPDATE_ERR_DELETE_PLXTOOLBAR_FOLDER' => 'An error occured while deleting core/plxtoolbar/ folder',
'L_UPDATE_FILE'						=> 'Updating file',
'L_UPDATE_ERR_FILE'					=> 'An error occured while updating file',
'L_UPDATE_PLUG_MOVEPARAMFILE'		=> 'Migration of plugins parameter file in the configuration folder',
'L_UPDATE_UPDATE_PLUGINS_FILE'		=> 'Updating plugins.xml',

);
?>

==> pluxml_5.5.orig.tar.gz: PluXml-5.5/core/lang/en/update.php <==
<?php

$LANG = array(

'L_SAVE_SUCCESSFUL'					=> 'Data was successfully saved',
'L_UPDATE_TITLE'					=> 'PluXml update',
'L_WRONG_PHP_VERSION'				=> 'PluXml requires PHP 5 or higher.',

'L_SELECT_LANG'						=> 'Choose your language',
'L_INPUT_CHANGE'					=> 'Change',

'L_UPDATE_UPTODATE'					=> 'Your PluXml has already been updated.',
'L_UPDATE_NOT_AVAILABLE'			=> 'No update available.',
'L_UPDATE_BACK'						=> 'Back to Home page',
'L_UPDATE_WARNING1'					=> 'You are about to update your old version of PluXml',
'L_UPDATE_SELECT_VERSION'			=> 'Please choose the old PluXml version you wish to update.',
'L_UPDATE_WARNING2'					=> 'If you can\'t find the old version of PluXml in the list below, then there is no automatic procedure to update, because your version is too old.<br />We advise you to download the latest version of <a href="http://www.pluxml.org">PluXml</a> and to make a new installation.',
'L_UPDATE_WARNING3'					=> 'Warning: before you start updating, don\'t forget to save a copy of your site by copying the "data" folder',
'L_UPDATE_START'					=> 'Start the update',

'L_UPDATE_ENDED'					=> 'Update complete',
'L_UPDATE_INPROGRESS'				=> 'Applying version updates',
'L_UPDATE_ERROR'					=> 'An error occured during the update.',
'L_UPDATE_SUCCESSFUL'				=> 'All the updates were successfully completed !',

'L_UPDATE_UPDATE_PARAMETERS_FILE'	=> 'Updating parametres.xml',
'L_UPDATE_CREATE_TAGS_FILE'			=> 'Creating tags.xml',
'L_UPDATE_ERR_CREATE_TAGS_FILE'		=> 'An error occured while creating tags.xml',
'L_UPDATE_CREATE_THEME_FILE'		=> 'Creating the theme file',
'L_UPDATE_ERR_CREATE_THEME_FILE'	=> 'An error occured while creating the file',
'L_UPDATE_ARTICLES_CONVERSION'		=> 'Converting articles to new format',
'L_UPDATE_ERR_FILE_PROCESSING'		=> 'Error in file processing',
'L_UPDATE_STATICS_MIGRATION'		=> 'Static page file migration',
'L_UPDATE_ERR_STATICS_MIGRATION'	=> 'An error occured while migrating static pages file',
'L_UPDATE_CREATE_USERS_FILE'		=> 'Creating users\' file',
'L_UPDATE_ERR_CREATE_USERS_FILE'	=> 'An error occured while creating users file',
'L_UPDATE_USERS_MIGRATION'			=> 'Migrating users\' file',
'L_UPDATE_ERR_USERS_MIGRATION'		=> 'An error occured while migrating users file',
'L_UPDATE_ERR_NO_USERS'				=> 'No user in the file',
'L_UPDATE_CREATE_HTACCESS_FILE'		=> 'Creating .htaccess file',
'L_UPDATE_ERR_CREATE_HTACCESS_FILE'	=> 'An error occured while creating .htaccess file',
'L_UPDATE_UPDATE_HTACCESS_FILE'		=> 'Updating .htaccess file',
'L_UPDATE_ERR_UPDATE_HTACCESS_FILE'	=> 'An error occured while updating .htaccess file',
'L_UPDATE_CATEGORIES_MIGRATION'		=> 'Migrating category file',
'L_UPDATE_ERR_CATEGORIES_MIGRATION'	=> 'An error occured while migrating category file',
'L_UPDATE_CREATE_PLUGINS_FILE'		=> 'Creating plugins.xml',
'L_UPDATE_ERR_CREATE_PLUGINS_FILE'	=> 'An error occured while creating plugins.xml',
'L_UPDATE_DELETE_FULLSCREEN_FILE'	=> 'Deleting core/admin/fullscreen.php',
'L_UPDATE_ERR_DELETE_FULLSCREEN_FILE'=> 'An error occured while deleting core/admin/fullscreen.php',
'L_UPDATE_DELETE_PLXTOOLBAR_FOLDER'	=>	'Deleting core/plxtoolbar/ folder',
'L_UPDATE_ERR_DELETE_PLXTOOLBAR_FOLDER' => 'An error occured while deleting core/plxtoolbar/ folder',
'L_UPDATE_FILE'						=> 'Updating file',
'L_UPDATE_ERR_FILE'					=> 'An error occured while updating file',
'L_UPDATE_PLUG_MOVEPARAMFILE'		=> 'Migration of plugins parameter file in the configuration folder',
'L_UPDATE_UPDATE_PLUGINS_FILE'		=> 'Updating plugins.xml',
'L_UPDATE_COMMENTS_MIGRATION'		=> 'Comments migration',
'L_UPDATE_ERR_COMMENTS_MIGRATION'	=> 'Error while migrating comments',
);
?>
